from distutils.core import setup

setup(

name='xuchangxin',	# 对外我们模块的名字

version='1.0', # 版本号

description='这是第一个对外发布的模块，测试哦',	#描述

author='luoluo', # 作者

author_email='910817507@qq.com',

py_modules=['xuchangxin.demo1','xuchangxin.demo2'] # 要发布的模块

)